@@ -1111,7 +1111,7 @@ class BasicDataApi(metaclass=Singleton):
                 return False
 
 
-    def get_fof_info(self, fof_id_list: Tuple[str] = ()):
+    def get_fof_info(self, manager_id: str, fof_id_list: Tuple[str] = ()):
         with BasicDatabaseConnector().managed_session() as db_session:
             try:
                 query = db_session.query(
@@ -1119,6 +1119,7 @@ class BasicDataApi(metaclass=Singleton):
                 )
                 if fof_id_list:
                     query = query.filter(
+                        FOFInfo.manager_id == manager_id,
                         FOFInfo.fof_id.in_(fof_id_list),
                     )
                 return pd.read_sql(query.statement, query.session.bind)
@@ -1417,12 +1418,17 @@ class BasicDataApi(metaclass=Singleton):
         try:
             df = self.get_asset_info()
             asset_list = df.asset_type.unique().tolist()
-            result = {}
+            result = []
             for asset_id in asset_list:
-                result[asset_id] = []
+                dic = {
+                    'title':asset_id,
+                    'items':[],
+                }
                 _df = df[df.asset_type == asset_id].drop_duplicates(subset=['asset_name'])
                 for r in _df.itertuples():
-                    result[asset_id].append([r.asset_id, r.asset_name])
+                    _dic = {'id':r.asset_id,'name':r.asset_name}
+                    dic['items'].append(_dic)
+                result.append(dic)
             return result
         except Exception as e:
             print(f'failed to get_fof_transit_money <err_msg> {e} from {AssetInfo.__tablename__}')
@@ -1502,10 +1508,10 @@ class BasicDataApi(metaclass=Singleton):
                 _df = self.get_index_price_dt(index_list=real_ids,start_date=begin_date,end_date=end_date).pivot_table(index='datetime',columns='index_id',values='close')
                 result.append(_df)
 
-            df_result = pd.concat(result,axis=1).sort_index().ffill().dropna()
-            df_result = df_result / df_result.iloc[0]
+            df_result = pd.concat(result,axis=1).sort_index()
+            df_result = df_result / df_result.bfill().iloc[0]
             df_result_show = df_result.rename(columns=asset_info.set_index('real_id').to_dict()['show_name'])
-            df_result_real = df_result.rename(columns=asset_info.set_index('real_id').to_dict()['real_name'])
+            df_result_real = df_result.ffill().rename(columns=asset_info.set_index('real_id').to_dict()['real_name'])
             df_result_show.index.name = 'datetime'
             df_result_real.index.name = 'datetime'
             asset_info = asset_info.drop_duplicates(subset=['real_id'])
@@ -1537,11 +1543,11 @@ class BasicDataApi(metaclass=Singleton):
                 if len(real_ids) > 0:
                     _df = self.get_index_price_dt(start_date=begin_date,end_date=end_date,index_list=real_ids).pivot_table(index='datetime',columns='index_id',values='close')
                     result.append(_df)
-                
-            df_result = pd.concat(result,axis=1).sort_index().ffill().dropna()
-            df_result = df_result / df_result.iloc[0]
+ 
+            df_result = pd.concat(result,axis=1).sort_index()
+            df_result = df_result / df_result.bfill().iloc[0]
             df_result = df_result.rename(columns=name_dic)
-            dic = {'data':df_result,'_input_asset_nav':df_result,'_input_asset_info':asset_info}
+            dic = {'data':df_result,'_input_asset_nav':df_result.ffill(),'_input_asset_info':asset_info}
             return dic
         
         except Exception as e:
@@ -1599,7 +1605,7 @@ class BasicDataApi(metaclass=Singleton):
         df.index.name = 'datetime'
         return df
 
-    def asset_recent_rate(self, asset_list, year:int=None):
+    def asset_recent_rate(self, asset_list, year:int=None, weekly:bool=False):
         #如果year为空 返回年度收益
         #如果year为整数 返回当年月度收益 year从2010开始
         try:
@@ -1656,33 +1662,40 @@ class BasicDataApi(metaclass=Singleton):
                 result.append(_df)
 
             index_price = pd.concat(result,axis=1).sort_index().ffill().dropna().rename(columns=name_dic)
-            if year is None:
-                # 年度
-                ## 年度收益净值调整
-                b_d = index_price.index.values[0]
-                if b_d < datetime.date(b_d.year,12,1):
-                    _b_d = datetime.date(b_d.year-1,12,31)
-                    index_price.loc[_b_d] = index_price.iloc[0]
-                    index_price = index_price.sort_index()
-                else:
-                    _b_d = index_price.loc[:datetime.date(b_d.year,12,31)].index[0]
-                    index_price = index_price.loc[_b_d:].copy()
-                index_price_y = self.data_resample_monthly_nav(index_price.bfill(),rule='12M')
-                index_ret_year = index_price_y.pct_change(1).dropna()
-                td = index_ret_year.index
-                td = [str(i.year) for i in td]
-                index_ret = index_ret_year.copy()
+            if weekly:
+                index_price_w = self.data_resample_monthly_nav(index_price,rule='1W').bfill()
+                index_ret = index_price_w.pct_change(1).dropna().tail(12)
+                td = index_ret.index
+                td = [i.strftime('%Y%m%d') for i in td]
             else:
-                index_price_m = index_price.loc[datetime.date(year-1,12,31):datetime.date(year,12,31)]
-                index_price_m = self.data_resample_monthly_nav(index_price_m,rule='1M').bfill()
-                index_ret_m = index_price_m.pct_change(1).dropna()
-                td = index_ret_m.index
-                td = [str(i.year) + str(i.month).zfill(2) for i in td ]
-                index_ret = index_ret_m.copy()
+                if year is None:
+                    # 年度
+                    ## 年度收益净值调整
+                    b_d = index_price.index.values[0]
+                    if b_d < datetime.date(b_d.year,12,1):
+                        _b_d = datetime.date(b_d.year-1,12,31)
+                        index_price.loc[_b_d] = index_price.iloc[0]
+                        index_price = index_price.sort_index()
+                    else:
+                        _b_d = index_price.loc[:datetime.date(b_d.year,12,31)].index[0]
+                        index_price = index_price.loc[_b_d:].copy()
+                    index_price_y = self.data_resample_monthly_nav(index_price.bfill(),rule='12M')
+                    index_ret_year = index_price_y.pct_change(1).dropna()
+                    td = index_ret_year.index
+                    td = [str(i.year) for i in td]
+                    index_ret = index_ret_year.copy()
+                else:
+                    index_price_m = index_price.loc[datetime.date(year-1,12,31):datetime.date(year,12,31)]
+                    index_price_m = self.data_resample_monthly_nav(index_price_m,rule='1M').bfill()
+                    index_ret_m = index_price_m.pct_change(1).dropna()
+                    td = index_ret_m.index
+                    td = [str(i.year) + str(i.month).zfill(2) for i in td ]
+                    index_ret = index_ret_m.copy()
+            last_day = td[-1]
             index_ret.index = td
+            index_ret = index_ret.T.sort_values(last_day, ascending=False).T
             index_ret.loc['均值',:] = index_ret.mean()
             index_ret = index_ret.round(4)*100
-            #index_ret = index_ret.rename(columns=desc_name_dic)
             index_ret = index_ret.T
             index_ret.index.name = 'index_id'
             return index_ret
@@ -1786,7 +1799,7 @@ class BasicDataApi(metaclass=Singleton):
             print(f'Failed to get data <err_msg> {e} from get_industry_price')
             return pd.DataFrame([])
 
-    def industry_recent_rate(self, industry_list, year:int=None):
+    def industry_recent_rate(self, industry_list, year:int=None, weekly:bool=False):
         try:
             df_info = self.get_index_info(industry_list)
             desc_name_dic = {r.index_id : r.desc_name.replace('(申万)','') for r in df_info.itertuples()}
@@ -1805,10 +1818,207 @@ class BasicDataApi(metaclass=Singleton):
                 td = index_ret_m.index
                 td = [str(i.year) + str(i.month).zfill(2) for i in td ]
                 index_ret = index_ret_m.copy()
+            if weekly:
+                index_price_w = self.data_resample_monthly_nav(index_price,rule='1W').bfill()
+                index_ret = index_price_w.pct_change(1).dropna().tail(12)
+                td = index_ret.index
+                td = [i.strftime('%Y%m%d') for i in td]
+            last_day = td[-1]
             index_ret.index = td
+            index_ret = index_ret.T.sort_values(last_day, ascending=False).T
             index_ret.loc['均值',:] = index_ret.mean()
             index_ret = index_ret.round(4)*100
             index_ret = index_ret.rename(columns=desc_name_dic)
             return index_ret.T
         except Exception as e:
-            print(f'failed to asset price <err_msg> {e} from basic.get_industry_recent_ret')
\ No newline at end of file
+            print(f'failed to asset price <err_msg> {e} from basic.get_industry_recent_ret')
+
+    def get_north_cap_data(self, begin_date, end_date, time_para):
+        try:
+            raw_api = RawDataApi()
+            begin_date, end_date = raw_api.get_date_range(time_para, begin_date, end_date)
+            index_price = self.get_index_price_dt(start_date=begin_date,end_date=end_date,index_list=['hs300'])
+            north_cap = raw_api.get_north_cap(begin_date, end_date)
+            index_price = index_price.pivot_table(index='datetime',values='close',columns='index_id')
+            north_cap =north_cap.set_index('datetime')[['north_cap']]
+            df = index_price.join(north_cap).rename(columns={'hs300':'沪深300','north_cap':'北向资金'})
+            return df
+        except Exception as e:
+            print(f'failed to asset price <err_msg> {e} from basic.get_north_cap_data')
+
+    def get_south_cap_data(self, begin_date, end_date, time_para):
+        try:
+            raw_api = RawDataApi()
+            begin_date, end_date = raw_api.get_date_range(time_para, begin_date, end_date)
+            index_price = self.get_index_price_dt(start_date=begin_date,end_date=end_date,index_list=['hsi'])
+            north_cap = raw_api.get_south_cap(begin_date, end_date)
+            index_price = index_price.pivot_table(index='datetime',values='close',columns='index_id')
+            north_cap =north_cap.set_index('datetime')[['south_cap']]
+            df = index_price.join(north_cap).rename(columns={'hsi':'恒生指数','south_cap':'南下资金'})
+            return df
+        except Exception as e:
+            print(f'failed to asset price <err_msg> {e} from basic.get_south_cap_data')
+
+    def get_side_cap_data(self, direction, begin_date, end_date, time_para):
+        try:
+            if direction == '北向资金':
+                return self.get_north_cap_data(begin_date, end_date, time_para)
+            else:
+                return self.get_south_cap_data(begin_date, end_date, time_para)
+        except Exception as e:
+            print(f'failed to asset price <err_msg> {e} from basic.get_side_cap_data')
+
+    def get_ppi(self, begin_date, end_date, time_para):
+        try:
+            raw = RawDataApi()
+            begin_date, end_date = raw.get_date_range(time_para, begin_date, end_date)
+            df = raw.get_em_macroeconomic_monthly(codes=['PPI'],start_date=begin_date,end_date=end_date)
+            df = df.drop(columns=['_update_time','codes']).rename(columns={'datetime':'日期','value':'同比'})
+            df.loc[:,'总增长'] = df.同比.cumsum()
+            index_price = self.get_index_price_dt(start_date=begin_date,end_date=end_date,index_list=['hs300'])
+            index_price = index_price.set_index('datetime')[['close']].loc[df.日期.values[0]:df.日期.values[-1]]
+            index_ret = round(index_price.close[-1] / index_price.close[0] - 1,3)
+            text = ['反映一定时期内全部工业产品出厂价格总水平的变动趋势和变动幅度的相对数。',
+                    '衡量工业企业产品出厂价格变动趋势和变动程度的指数，是反映某一时期生产领域价格变动情况的重要经济指标。',
+                    '由生产成本、利润和税金三部分组成，它是工业产品进入流通领域的最初价格。',
+                    '指数比预期数值高时，表明有通货膨胀的风险；指数比预期数值低时，则表明有通货紧缩的风险。']
+            data = {
+                '工业品出场PPI':df,
+                '沪深300总增长':index_ret,
+                '介绍':text,
+            }
+            return data
+        except Exception as e:
+            print(f'Failed to get data <err_msg> {e} from basic.get_ppi')
+            return pd.DataFrame([])
+    
+    def get_pmi(self, begin_date, end_date, time_para):
+        try:
+            raw = RawDataApi()
+            begin_date, end_date = raw.get_date_range(time_para, begin_date, end_date)
+            l = ['CX_PMI','PMI','NonPMI']
+            df = raw.get_em_macroeconomic_monthly(codes=l)
+            info = raw.get_em_macroeconomic_info(codes=l)
+            name_dic = info.set_index('codes').to_dict()['desc_name']
+            name_dic['CX_PMI'] = '财新PMI'
+            df = df.pivot_table(index='datetime',columns='codes',values='value').dropna().rename(columns=name_dic)
+            pct_chg = lambda x: x[-1] / x[0] - 1
+            df.loc[:,'财新PMI同比'] = df.财新PMI.rolling(window=13).apply(pct_chg)
+            df.loc[:,'非制造业PMI同比'] = df.非制造业PMI.rolling(window=13).apply(pct_chg)
+            df.loc[:,'PMI同比'] = df.PMI.rolling(window=13).apply(pct_chg)
+            df = df.loc[begin_date:end_date]
+            text = ['衡量一个国家制造业的 “体检表”，是制造业在生产、新订单、商品价格、存货、 雇员、订单交货、新出口订单和进口等八个方面状况的指数。',
+                    'PMI指数50为荣枯分水线。PMI略大于50，说明经济在缓慢前进，PMI略小于50说明经济在慢慢走向衰退。']
+            data = {
+                'data':df,
+                'text':text,
+            }
+            return data
+        except Exception as e:
+            print(f'Failed to get data <err_msg> {e} from basic.get_pmi')
+            return pd.DataFrame([])
+
+    def get_gdp(self, begin_date, end_date, time_para):
+        try:
+            l = ['gdp_cum_yoy',
+                'gdp_i1_c_yoy',
+                'gdp_i1_s_w',
+                'gdp_i2_c_yoy',
+                'gdp_i2_s_w',
+                'gdp_i3_c_yoy',
+                'gdp_i3_s_w',
+                ]
+            raw = RawDataApi()
+            begin_date, end_date = raw.get_date_range(time_para, begin_date, end_date)
+            df = raw.get_em_macroeconomic_monthly(codes=l,start_date=begin_date,end_date=end_date)
+            info = raw.get_em_macroeconomic_info(codes=l)
+            desc_dic = info.set_index('codes').to_dict()['desc_name']
+            df = df.pivot_table(index='datetime',columns='codes',values='value')
+            df = df.rename(columns=desc_dic)
+            name_dic = {
+                'GDP：累计同比':'总GDP同比增速',
+                'GDP第一产业累计同比':'第一产业同比增速',
+                '第一产业GDP当季占比':'第一产业当季贡献',
+                'GDP第二产业累计同比':'第二产业同比增速',
+                '第二产业GDP当季占比':'第二产业当季贡献',
+                'GDP第三产业累计同比':'第三产业同比增速',
+                '第三产业GDP当季占比':'第三产业当季贡献',
+            }
+            df = df.rename(columns=name_dic)
+            text = [
+                '国内生产总值，简称GDP，是指在一定时期内（一个季度或一年），全国经济中所生产出的全部最终产品和劳务的价值。',
+                '第一产业主要指生产食材以及其它一些生物材料的产业，包括种植业、林业、畜牧业、水产养殖业等直接以自然物为生产对象的产业。',
+                '第二产业主要指加工制造产业，利用自然界和第一产业提供的基本材料进行加工处理。',
+                '第三产业是指第一、第二产业以外的其他行业，范围比较广泛，主要包括交通运输业、通讯产业、商业、餐饮业、金融业、教育、公共服务等非物质生产部门。',
+            ]
+            data = {
+                'data':df,
+                'text':text
+            }
+            return data
+
+        except Exception as e:
+            print(f'Failed to get data <err_msg> {e} from basic.get_gdp')
+            return pd.DataFrame([])
+
+    def get_cpi(self, begin_date, end_date, time_para):
+        try:
+            l = ['CPI','CPI_mom']
+            raw = RawDataApi()
+            begin_date, end_date = raw.get_date_range(time_para, begin_date, end_date)
+            df = raw.get_em_macroeconomic_monthly(codes=l,start_date=begin_date,end_date=end_date)
+            df = df.pivot_table(columns='codes',values='value',index='datetime').dropna()
+            _df = (df['CPI_mom']/100 + 1).cumprod()
+            df.loc[:,'CPI估算指数'] = _df / _df.iloc[0]
+            df = df.drop(columns=['CPI_mom'])
+            index_price = BasicDataApi().get_index_price_dt(start_date=df.index[0],end_date=df.index[-1],index_list=['hs300'])
+            index_price = index_price.pivot_table(index='datetime',values='close',columns='index_id')
+            index_price = index_price.reindex(index_price.index.union(df.index).sort_values()).ffill()
+            df = df.join(index_price).dropna().rename(columns={'hs300':'沪深300'})
+            return df
+        except Exception as e:
+            print(f'Failed to get data <err_msg> {e} from basic.get_cpi')
+            return pd.DataFrame([])
+
+    def get_ah_prem(self, begin_date, end_date, time_para):
+        try:
+            raw = RawDataApi()
+            index_id = 'em_ah_prem'
+            begin_date, end_date = raw.get_date_range(time_para, begin_date, end_date)
+            index_price = BasicDataApi().get_index_price_dt(start_date=begin_date,end_date=end_date,index_list=[index_id])
+            index_price = index_price.pivot_table(index='datetime',values='close',columns='index_id')
+            index_price = index_price.rename(columns={index_id:'AH股溢价指数'})
+            return index_price
+
+        except Exception as e:
+            print(f'Failed to get data <err_msg> {e} from basic.get_ah_prem')
+            return pd.DataFrame([])
+
+    def get_us_bond_rate(self, begin_date, end_date, time_para):
+        try:
+            rate_dic = {
+                'US_TB_10Y':'美国十年期国债收益率',
+                'US_TB_2Y':'美国两年期国债收益率',
+                'US_TB_3M':'美国三月期国债收益率',
+                'US_TB_5Y':'美国五年期国债收益率'
+            }
+            raw = RawDataApi()
+            begin_date, end_date = raw.get_date_range(time_para, begin_date, end_date)
+            us_debt = raw.get_em_macroeconomic_daily(codes=rate_dic.keys(),start_date=begin_date, end_date=end_date)
+            df = us_debt.pivot_table(index='datetime',values='value',columns='codes').dropna()
+            df = df.rename(columns=rate_dic)
+            return df
+        except Exception as e:
+            print(f'Failed to get data <err_msg> {e} from basic.get_us_bond_rate')
+            return pd.DataFrame([])
+
+    def get_usd_index(self, begin_date, end_date, time_para):
+        try:
+            raw = RawDataApi()
+            begin_date, end_date = raw.get_date_range(time_para, begin_date, end_date)
+            rates = RawDataApi().get_raw_cm_index_price_df(start_date=begin_date,end_date=end_date)
+            rates = rates[['datetime','usd_central_parity_rate']].rename(columns={'usd_central_parity_rate':'美元指数'})
+            return rates
+        except Exception as e:
+            print(f'Failed to get data <err_msg> {e} from basic.get_usd_index')
+            return pd.DataFrame([])
\ No newline at end of file
