@@ -4,7 +4,9 @@ from typing import Tuple, List
 import pandas as pd
 import datetime
 from sqlalchemy import func
-
+import statsmodels.api as sm
+from statsmodels import regression
+import numpy as np
 from ...util.singleton import Singleton
 from ..wrapper.mysql import DerivedDatabaseConnector
 from .raw import RawDataApi
@@ -183,62 +185,51 @@ class DerivedDataApi(metaclass=Singleton):
                 print(f'Failed to get data <err_msg> {e} from {IndexValuationLongTerm.__tablename__}')
                 return pd.DataFrame([])
 
-    def get_index_val_info(self):
-        dic = {
-            'A股指数PE估值':{
-                'index_ids':['sse50','hs300','csi500','gem_50'],
-                'val':'pe_ttm',
-            },
-            'A股指数PB估值':{
-                'index_ids':['sse50','hs300','csi500','gem_50'],
-                'val':'pb_mrq',
-            },
-            '港股指数PE估值':{
-                'index_ids':['hsi','hsi_stateown','hsi_ita','hsi_china25','hsi_mssize','hsi_shkscne','hsi_intertec'],
-                'val':'pe_ttm',
-            },
-            '港股指数PB估值':{
-                'index_ids':['hsi','hsi_stateown','hsi_ita','hsi_china25','hsi_mssize','hsi_shkscne','hsi_intertec'],
-                'val':'pb_mrq',
-            },
-            '风格指数PE估值':{
-                'index_ids':['csi300_growth','csi300_value','csi800_value','csi800_growth'],
-                'val':'pe_ttm',
-            },
-            '风格指数PB估值':{
-                'index_ids':['csi300_growth','csi300_value','csi800_value','csi800_growth'],
-                'val':'pb_mrq',
-            },
-            '行业指数PE估值':{
-                'index_ids':BasicDataApi().get_asset_info_by_type(['行业指数']).real_id.tolist(),
-                'val':'pe_ttm',
-            },
-            '行业指数PB估值':{
-                'index_ids':BasicDataApi().get_asset_info_by_type(['行业指数']).real_id.tolist(),
-                'val':'pb_mrq',
-            },
-            '主题指数PE估值':{
-                'index_ids':BasicDataApi().get_asset_info_by_type(['主题指数']).real_id.tolist(),
-                'val':'pe_ttm',
-            },
-            '主题指数PB估值':{
-                'index_ids':BasicDataApi().get_asset_info_by_type(['主题指数']).real_id.tolist(),
-                'val':'pb_mrq',
-            },
-        }
-        return dic
+    def get_index_pair(self):
+        index_val = {'PE':'pe_ttm','PB':'pb_mrq','ROE':'roe'}
+        return index_val
 
-    def get_index_val_detail(self):
-        index_group = ['A股指数','港股指数','风格指数','行业指数','主题指数']
-        index_val = ['PE','PB']
-        data = {'index_group':index_group,'index_val':index_val}
+    def get_index_val_info(self):
+        index_info = BasicDataApi().get_index_info()
+        desc_df = index_info.set_index('index_id').to_dict()['desc_name']
+        info_dic = {
+            'A股指数':['sse50','hs300','csi500','gem_50'],
+            '港股指数':['hsi','hsi_stateown','hsi_ita','hsi_china25','hsi_mssize','hsi_shkscne','hsi_intertec'],
+            '风格指数':['csi300_growth','csi300_value','csi_grow500','csi_v500','csi800_value','csi800_growth'],
+        }
+        info_list = ['行业指数','主题指数']
+        asset_info = BasicDataApi().get_asset_info_by_type(info_list)
+        result = []
+        for asset_id, index_list in info_dic.items():
+            dic = {'title':asset_id,'items':[]}
+            for index_id in index_list:
+                _dic = {
+                    'id':index_id,
+                    'name':desc_df[index_id],
+                }
+                dic['items'].append(_dic)
+            result.append(dic)
+
+        for asset_id in info_list:
+            _df = asset_info[asset_info.asset_type == asset_id]
+            dic = {'title':asset_id,'items':[]}
+            for i in _df.itertuples():
+                _dic = {
+                    'id':i.real_id,
+                    'name':i.asset_name,
+                }
+                dic['items'].append(_dic)
+            result.append(dic)
+        index_val = self.get_index_pair()
+        data = {'index_group':result,'index_val':list(index_val.keys())}
         return data
 
-    def get_index_valuation_with_period(self, begin_date, end_date, time_para, index_group='A股指数', index_val='PE'):
-        data_type = f'{index_group}{index_val}估值'
-        inputs_dic = self.get_index_val_info()
-        index_ids = inputs_dic[data_type]['index_ids']
-        columns = [inputs_dic[data_type]['val']]
+    def get_index_valuation_with_period(self, begin_date, end_date, time_para, index_list, valuation_type='PE'):
+        index_val = valuation_type
+        data_type = f'{index_val}估值'
+        inputs_dic = self.get_index_pair()
+        columns = [inputs_dic[index_val]]
+        
         begin_date, end_date = RawDataApi().get_date_range(time_para, begin_date, end_date)
         with DerivedDatabaseConnector().managed_session() as mn_session:
             try:
@@ -246,14 +237,14 @@ class DerivedDataApi(metaclass=Singleton):
                     IndexValuationLongTerm.index_id,
                     IndexValuationLongTerm.datetime,
                 ).add_columns(*columns).filter(
-                    IndexValuationLongTerm.index_id.in_(index_ids),
+                    IndexValuationLongTerm.index_id.in_(index_list),
                     IndexValuationLongTerm.datetime >= begin_date,
                     IndexValuationLongTerm.datetime <= end_date,
                 ).order_by(IndexValuationLongTerm.datetime.asc())
                 df = pd.read_sql(query.statement, query.session.bind)
                 l = df.columns.tolist()
                 value_col = [i for i in l if i not in ['datetime','index_id']][0]
-                index_info = BasicDataApi().get_index_info(index_ids)
+                index_info = BasicDataApi().get_index_info(index_list)
                 desc_dic = index_info.set_index('index_id').to_dict()['desc_name']
                 df = df.pivot_table(columns='index_id',values=value_col,index='datetime')
                 df.loc['中位数',:] = df.median()
@@ -270,6 +261,24 @@ class DerivedDataApi(metaclass=Singleton):
                 print(f'Failed to get data <err_msg> {e} from {IndexValuationLongTerm.__tablename__}')
                 return pd.DataFrame([])
 
+    def get_index_valuation_last_date(self, dt, index_ids=[]):
+        with DerivedDatabaseConnector().managed_session() as db_session:
+            try:
+                dt = db_session.query(
+                    func.max(IndexValuationLongTerm.datetime)).filter(
+                            IndexValuationLongTerm.index_id.in_(index_ids), 
+                            IndexValuationLongTerm.datetime <= dt,
+                ).one_or_none()[0]
+                query = db_session.query(IndexValuationLongTerm).filter(
+                        IndexValuationLongTerm.datetime == dt,
+                        IndexValuationLongTerm.index_id.in_(index_ids),
+                    )
+                df = pd.read_sql(query.statement, query.session.bind)
+                return df
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {IndexValuationLongTerm.__tablename__}')
+                return pd.DataFrame([])
+
     def get_index_valuation_develop_without_date(self, index_ids):
         with DerivedDatabaseConnector().managed_session() as mn_session:
             try:
@@ -677,7 +686,7 @@ class DerivedDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'failed to get_fof_nav <err_msg> {e} from {FOFNav.__tablename__}')
 
-    def delete_fof_nav(self, date_to_delete: datetime.date, fof_id_list: List[str]) -> bool:
+    def delete_fof_nav(self, date_to_delete: datetime.date, manager_id: str, fof_id_list: List[str]) -> bool:
         with DerivedDatabaseConnector().managed_session() as session:
             try:
                 session.query(
@@ -685,6 +694,7 @@ class DerivedDataApi(metaclass=Singleton):
                 ).filter(
                     FOFNav.fof_id.in_(fof_id_list),
                     FOFNav.datetime == date_to_delete,
+                    FOFNav.manager_id == manager_id,
                 ).delete(synchronize_session=False)
                 session.commit()
                 return True
@@ -822,11 +832,13 @@ class DerivedDataApi(metaclass=Singleton):
                 print(f'failed to delete data <err_msg> {e} from {FOFPositionDetail.__tablename__}')
                 return False
 
-    def get_hedge_fund_investor_pur_redemp(self, fof_id_list: Tuple[str] = ()):
+    def get_hedge_fund_investor_pur_redemp(self, manager_id: str, fof_id_list: Tuple[str] = ()):
         with DerivedDatabaseConnector().managed_session() as db_session:
             try:
                 query = db_session.query(
                     HedgeFundInvestorPurAndRedemp,
+                ).filter(
+                    HedgeFundInvestorPurAndRedemp.manager_id == manager_id,
                 )
                 if fof_id_list:
                     query = query.filter(
@@ -909,4 +921,200 @@ class DerivedDataApi(metaclass=Singleton):
             return df
         except Exception as e:
             print(f'failed to get data <err_msg> {e} from derived.get_style_factor_ret')
+            return False
+
+    def get_industry_stock_ret_and_size(self, begin_date, end_date, time_para):
+        try:
+            # 建议只用短时间，上时间慢
+            raw_api = RawDataApi()
+            basic_api = BasicDataApi()
+            begin_date, end_date = raw_api.get_date_range(time_para, begin_date, end_date)
+            stock_df = raw_api.get_em_stock_info()
+            stock_df = stock_df[['stock_id','name','bl_sws_ind_code']].dropna()
+            stock_df.loc[:,'industry_1'] = stock_df.bl_sws_ind_code.map(lambda x: x.split('-')[0])
+            stock_df.loc[:,'industry_2'] = stock_df.bl_sws_ind_code.map(lambda x: x.split('-')[1])
+            stock_df = stock_df.drop(columns=['bl_sws_ind_code']).set_index('stock_id')
+            industry_df = raw_api.get_em_industry_info()
+            industry_dic_name = industry_df.set_index('em_id').to_dict()['ind_name']
+            stock_df.loc[:,'industry_1_name'] = stock_df.industry_1.map(industry_dic_name)
+            stock_df.loc[:,'industry_2_name'] = stock_df.industry_2.map(industry_dic_name)
+            stock_list = stock_df.index.tolist()
+            total_share = raw_api.get_em_daily_info_last_date(stock_list=stock_list,columns=['total_share'])
+            total_share = total_share.pivot_table(index='stock_id',columns='datetime',values='total_share')
+            total_share.columns = ['total_share']
+            stock_price = raw_api.get_em_stock_price(start_date=begin_date, end_date=end_date,stock_list=stock_list,columns=['close'])
+            last_date = sorted(stock_price.datetime.unique().tolist())[-1]
+            last_price = stock_price[stock_price['datetime'] == last_date]
+            size_df = last_price.set_index('stock_id')[['close']].join(total_share).dropna()
+            size_df.loc[:,'size'] = size_df.close*size_df.total_share
+            stock_df = stock_df.join(size_df[['size']]).dropna()
+            indus_size_1 = stock_df[['industry_1','size']].groupby('industry_1').sum()
+            indus_size_2 = stock_df[['industry_2','size']].groupby('industry_2').sum()
+            stock_price = stock_price.pivot_table(index='datetime',columns='stock_id',values='close').ffill()
+            stock_ret = pd.DataFrame(stock_price.iloc[-1] / stock_price.iloc[0] - 1)
+            stock_ret.columns=['stock_ret']
+            stock_df = stock_df.join(stock_ret).dropna()
+            industry_list = indus_size_1.index.tolist() + indus_size_2.index.tolist()
+            index_info = basic_api.get_index_info_by_em_id(em_id_list=industry_list)
+            industry_dic = index_info.set_index('index_id').to_dict()['em_id']
+            index_list = list(industry_dic.keys())
+            industry_price = basic_api.get_index_price_dt(start_date=begin_date,end_date=end_date,index_list=index_list,columns=['close'])
+            industry_price = industry_price.pivot_table(columns='index_id',values='close',index='datetime').ffill()
+            industry_price = industry_price.rename(columns=industry_dic)
+            indus_ret = pd.DataFrame(industry_price.iloc[-1] / industry_price.iloc[0] - 1)
+            indus_ret.columns= ['industry_ret']
+            indus_size_1 = indus_size_1.join(indus_ret).dropna()
+            indus_size_2 = indus_size_2.join(indus_ret).dropna()
+            indus_size_1.loc[:,'industry_1_name'] = indus_size_1.index.map(industry_dic_name)
+            indus_size_2.loc[:,'industry_2_name'] = indus_size_2.index.map(industry_dic_name)
+            _df = stock_df.reset_index().set_index('industry_2')[['industry_1']]
+            _df = _df[~_df.index.duplicated(keep='first')]
+            indus_size_2 = indus_size_2.join(_df)
+            data = {
+                '股票收益':stock_df,
+                '行业一级收益':indus_size_1,
+                '行业二级收益':indus_size_2,
+            }
+            return data
+        except Exception as e:
+            print(f'failed to get data <err_msg> {e} from derived.get_industry_stock_ret_and_size')
+            return False
+        
+    def get_all_industry_val(self, begin_date, end_date, time_para):
+        try:
+            raw_api = RawDataApi()
+            begin_date, end_date = raw_api.get_date_range(time_para, begin_date, end_date)
+            dic = {
+                'pb_mrq':'PB',
+                'roe':'ROE'
+            }
+            index_info = BasicDataApi().get_asset_info_by_type(['行业指数'])
+            index_ids = index_info.real_id.tolist()
+            asset_name = index_info.set_index('real_id').to_dict()['asset_name']
+            df = self.get_index_valuation_last_date(dt=end_date, index_ids=index_ids)
+            df = df.set_index('index_id')[dic.keys()].rename(columns=dic).round(2)
+            df.loc[:,'desc_name'] = df.index.map(asset_name)
+            df = df.reset_index(drop=True)
+            _x = df.ROE.values
+            x = sm.add_constant(_x)
+            y = df.PB.values
+            model = regression.linear_model.OLS(y,x).fit()
+            c = model.params[0]
+            k = model.params[1]
+            x_array = np.arange(min(_x),max(_x), (max(_x)-min(_x))/100)
+            y_array = k*x_array + c
+            df_line = pd.DataFrame({'ROE':x_array,'PB':y_array,}).round(2)
+            data = {
+                '散点':df,
+                '虚线':df_line,
+            }
+            return data
+        except Exception as e:
+            print(f'failed to get data <err_msg> {e} from derived.get_all_industry_val')
+            return False
+
+    def index_val_history_info(self):   
+        try:
+            asset_list = ['行业指数','主题指数']
+            index_info = BasicDataApi().get_asset_info_by_type(asset_list)
+            result = {'大类资产':[['hs300','沪深300'],['csi500','中证500'],['gem','创业板']]}
+            for asset_id in asset_list:
+                _dfi = index_info[index_info['asset_type'] == asset_id]
+                result[asset_id]=[]
+                for r in _dfi.itertuples():
+                    result[asset_id].append([r.real_id,r.asset_name])
+            return result
+        except Exception as e:
+            print(f'failed to get data <err_msg> {e} from derived.index_val_history_info')
+            return False
+
+    def stock_debt_val_info(self):
+        index_list = ['sse50','hs300','csi500','csi1000','gem']
+        index_info = BasicDataApi().get_index_info(index_list)
+        index_info = [[r.index_id, r.desc_name] for r in index_info.itertuples()]
+        valuation_type = [['PE','风险溢价'],['DY','股息率溢价']]
+        debt_ret_list = [['TB_1Y','1年国债收益率'],['TB_3Y','3年国债收益率'],['TB_5Y','5年国债收益率'],['TB_10Y','10年国债收益率']]
+        
+        data = {
+            'index_list':index_info,
+            'valuation_type':valuation_type,
+            'debt_ret_list':debt_ret_list,
+        }
+        return data
+
+    def stock_debt_val_detail(self, index_id, valuation_type,debt_ret_index):
+        try:
+            dic = {
+                'pe_ttm':'PE',
+                'dy':'DY',
+            }
+            title_dic = {
+                'PE':'风险溢价',
+                'DY':'股息率溢价',
+            }
+            bond_yield = RawDataApi().get_em_macroeconomic_daily(codes=[debt_ret_index])
+            index_risk = DerivedDataApi().get_index_valuation_develop_without_date(index_ids=[index_id])
+            index_info = BasicDataApi().get_index_info([index_id])
+            index_name = index_info.set_index('index_id').loc[index_id,'desc_name']
+
+            index_risk = index_risk.set_index('datetime').rename(columns=dic)[[valuation_type]].join(bond_yield.set_index('datetime').rename(columns={'value':'debt_ret'})['debt_ret']).ffill()
+
+            pctrank = lambda x: x.rank(pct=True).iloc[-1]
+            if valuation_type == 'PE':
+                index_risk.loc[:,'reverse_val'] = 1 / index_risk[valuation_type]
+            else:
+                index_risk.loc[:,'reverse_val'] = index_risk[valuation_type]
+            index_risk.loc[:,'debt_ret'] = index_risk.debt_ret / 100
+            index_risk.loc[:,'risk_value'] = index_risk.reverse_val - index_risk.debt_ret
+
+            min_periods = int(3*242)
+            window = index_risk.shape[0]
+            window= 5 * 242
+            index_risk['risk_values_pct'] = index_risk.risk_value.rolling(window=window, min_periods=min_periods).apply(pctrank, raw=False)
+            index_col_pct = 'risk_values_pct'
+            index_col = 'risk_value'
+            diff = 0.00
+            a1 = index_risk[index_risk[index_col_pct] >= (0.90 - diff)][[index_col]].rename(columns={index_col:'区间分位最高10%'})
+            a2 = index_risk[(index_risk[index_col_pct] <= (0.90 + diff))&(index_risk[index_col_pct] >= 0.7-diff)][[index_col]].rename(columns={index_col:'区间分位最高30%'})
+            a3 = index_risk[(index_risk[index_col_pct] <= (0.7 + diff))&(index_risk[index_col_pct] >= 0.3-diff)][[index_col]].rename(columns={index_col:'中间区间分位'})
+            a4 = index_risk[(index_risk[index_col_pct] <= 0.3+diff)&(index_risk[index_col_pct] >= 0.05-diff)][[index_col]].rename(columns={index_col:'区间分位最低30%'})
+            a5 = index_risk[(index_risk[index_col_pct] <= 0.1+diff)][[index_col]].rename(columns={index_col:'区间分位最低10%'})
+            am = pd.DataFrame(index_risk[index_col].rolling(window=window,min_periods=min_periods).mean())
+            am.columns=['均值']
+            df = pd.concat([a1,a2,a3,a4,a5,am],axis=1).sort_index().dropna(axis=0,how='all')
+            title = index_name +title_dic[valuation_type]
+            data = {
+                'data':df,
+                'title':title,
+            }
+            return data
+        except Exception as e:
+            print(f'failed to get data <err_msg> {e} from derived.stock_debt_val_detail')
+            return False
+
+    def industry_beta(self):
+        try:
+            index_info = BasicDataApi().get_asset_info_by_type(['行业指数'])
+            index_ids = index_info.real_id.tolist()
+            df = DerivedDataApi().get_index_valuation_develop_without_date(index_ids=index_ids)
+            pb_df = df.pivot_table(index='datetime',values='pb_mrq',columns='index_id')
+            roe_df = df.pivot_table(index='datetime',values='roe',columns='index_id')   
+            result = []
+            dt_list = pb_df.index.tolist()
+            for idx, dt, in enumerate(dt_list):
+                if idx % 10 != 0:
+                    continue
+                _x = roe_df.loc[dt].dropna()
+                x = sm.add_constant(_x)
+                y = np.log(pb_df.loc[dt].dropna())
+                model = regression.linear_model.OLS(y,x).fit()
+                beta = model.params[1]
+                result.append({'datetime':dt,'beta':beta})
+            _df = pd.DataFrame(result).set_index('datetime')
+            index_price = BasicDataApi().get_index_price_dt(start_date=_df.index[0],end_date=_df.index[-1],index_list=['hs300'])
+            index_price = index_price.pivot_table(index='datetime',values='close',columns='index_id')
+            _df = _df.join(index_price).ffill().reset_index()
+            return _df
+        except Exception as e:
+            print(f'failed to get data <err_msg> {e} from derived.stock_debt_val_detail')
             return False
\ No newline at end of file
