@@ -111,6 +111,8 @@ class OverseaFundNavAnalysis:
         res = []
         for code_i in codes_list:
             exsited_dt = df_old[df_old.codes == code_i]
+            if exsited_dt.empty:
+                continue
             exsited_dt = pd.to_datetime(exsited_dt.datetime.values[-1]).date()
             _df = df_new[(df_new.codes == code_i)&(df_new.datetime > exsited_dt)]
             # idx = codes_list.index(code_i)
@@ -191,6 +193,57 @@ class OverseaFundNavAnalysis:
         return failed_tasks
 
     def process_indicators(self):
+
+        dic = {
+            'cumu_ret':'累计收益',
+            'annual_ret':'年化收益',
+            'annual_vol':'年化波动',
+            'sharpe':'夏普',
+            'recent_1w_ret':'最近一个周收益',
+            'recent_1m_ret':'最近一个月收益',
+            'recent_3m_ret':'最近三个月收益',
+            'recent_6m_ret':'最近六个月收益',
+            'recent_1y_ret':'最近一年收益',
+            'recent_3y_ret':'最近三年收益',
+            'recent_5y_ret':'最近五年收益',
+            'worst_3m_ret':'最差三个月收益',
+            'worst_6m_ret':'最差六个月收益',
+            'last_mv_diff':'最新涨跌幅',
+            'last_increase_rate':'最新涨跌',
+            'recent_drawdown':'当前回撤',
+            'recent_mdd_date1':'当前回撤开始时间',
+            'recent_mdd_lens':'当前回撤持续天数',
+            'mdd':'最大回撤',
+            'mdd_date1':'最大回撤开始日',
+            'mdd_date2':'最大回撤结束日',
+            'mdd_lens':'最大回撤持续天数',
+            'calmar':'卡玛比率',
+            'downside_risk':'下行风险',
+            'sortino':'索提诺',
+            'var':'风险价值',
+            'ervar':'风险价值调整比',
+            'skew':'偏度',
+            'kurtosis':'峰度',
+            'alpha_cl':'选股收益',
+            'beta_cl':'择时收益',
+            'beta_bear':'熊市beta', 
+            'beta_bull':'牛市beta',
+            'excess_ret':'相对收益',
+            'win_rate':'胜率',
+            'corr':'相关性',
+            'track_err':'跟踪误差',
+            'info':'信息比率',
+            'alpha':'alpha',
+            'beta':'beta',
+            'treynor':'特雷诺',
+            'not_system_risk':'非系统性风险',
+            'cvar':'条件风险价值',
+            'up_capture':'上行捕捉率',
+            'down_capture':'下行捕捉率',
+            'excess_ret_cotinue':'超额收益持续性',
+            'continue_value_m':'业绩持续性',
+        }
+
         failed_tasks: List[str] = []
         try:
             res = []
@@ -338,6 +391,8 @@ class OverseaFundNavAnalysis:
             df = pd.DataFrame(res)
             df = df.replace(np.Inf,np.nan).replace(-np.Inf, np.nan)
             df = df.replace(np.Inf,np.nan).replace(-np.Inf, np.nan)
+            total_columns = list(QSFundRecentRet.__table__.columns.keys())
+            df = df[df.columns.intersection(total_columns)]
             self._data_helper._upload_raw(df, QSFundRecentRet.__table__.name, to_truncate=True)
         except Exception as e:
             print(e)
@@ -349,7 +404,7 @@ class OverseaFundNavAnalysis:
         self.init(end_date)
         failed_tasks = []
         failed_tasks.extend(self.process_fund_ret())
-        failed_tasks.extend(self.process_current_mdd())
+        #failed_tasks.extend(self.process_current_mdd())
         failed_tasks.extend(self.process_monthly_ret())
         failed_tasks.extend(self.process_period_ret())
         failed_tasks.extend(self.process_recent_ret())
