@@ -337,18 +337,23 @@ class OtherRawDataDownloader:
         self._data_helper._upload_raw(df, OSFundBenchmarks.__table__.name)
 
     def fund_nav_adj_process(self):
-        os_nav_div_factor = RawDataApi().get_os_fund_nav_div_factor().drop(columns='_update_time')
-        os_nav_div_factor = os_nav_div_factor.pivot(index='ex_date', columns='product_id', values='factor')
-        os_nav = RawDataApi().get_oversea_fund_nav()
-        os_nav = os_nav.drop(columns='_update_time').pivot(index='datetime', columns='codes', values='nav')
-        os_nav_div_factor = os_nav_div_factor.reindex(os_nav.index.union(os_nav_div_factor.index))
-        os_nav_div_factor.iloc[0, :].fillna(1)
-        os_nav_div_factor = os_nav_div_factor.ffill()
-        os_nav_div_factor = os_nav_div_factor[os_nav_div_factor.index <= os_nav.index.max()]
-        adj_nav = os_nav.ffill().mul(os_nav_div_factor, fill_value=1)
-        df = pd.DataFrame(adj_nav.stack())
-        df.columns = ['nav']
-        df = df.reset_index()
-        df = df.rename(columns={'level_1':'codes'})
-        #df.to_sql('oversea_fund_nav_adj', RawDatabaseConnector().get_engine(), index=False, if_exists='append')
-        self._data_helper._upload_raw(df, OSFundNavAdj.__table__.name, to_truncate=True)
\ No newline at end of file
+        try:
+            os_nav_div_factor = RawDataApi().get_os_fund_nav_div_factor().drop(columns='_update_time')
+            os_nav_div_factor = os_nav_div_factor.pivot(index='ex_date', columns='product_id', values='factor')
+            os_nav = RawDataApi().get_oversea_fund_nav()
+            os_nav = os_nav.drop(columns='_update_time').pivot(index='datetime', columns='codes', values='nav')
+            os_nav_div_factor = os_nav_div_factor.reindex(os_nav.index.union(os_nav_div_factor.index))
+            os_nav_div_factor.iloc[0, :].fillna(1)
+            os_nav_div_factor = os_nav_div_factor.ffill()
+            os_nav_div_factor = os_nav_div_factor[os_nav_div_factor.index <= os_nav.index.max()]
+            adj_nav = os_nav.ffill().mul(os_nav_div_factor, fill_value=1)
+            df = pd.DataFrame(adj_nav.stack())
+            df.columns = ['nav']
+            df = df.reset_index()
+            df = df.rename(columns={'level_1':'codes'})
+            #df.to_sql('oversea_fund_nav_adj', RawDatabaseConnector().get_engine(), index=False, if_exists='append')
+            self._data_helper._upload_raw(df, OSFundNavAdj.__table__.name, to_truncate=True)
+            return True
+        except Exception as e:
+            print(e)
+            return False
\ No newline at end of file
