@@ -71,9 +71,10 @@ class RawDataDownloader:
                     # 表明本非周末，今天不需要更新
                     print(f'monthly indicator update on every weekend, not today {end_date_dt}')
                 else:
-                    failed_tasks.extend(self.oversea_download_long_term.update_fund_adj_factor())
-                    failed_tasks.extend(self.other_raw_data_downloader.fund_nav_adj_process())
-
+                    if not self.oversea_download_long_term.update_fund_adj_factor():
+                        failed_tasks.append('oversea_fund_adj_factor')
+                    if not self.other_raw_data_downloader.fund_nav_adj_process():
+                        failed_tasks.append('oversea_fund_nav_adj_process')
         return failed_tasks
 
     def get_updated_count(self):
