@@ -27,6 +27,7 @@ class HedgeFundNAVReader:
         '基金份额净值': 'net_asset_value',
         '单位净值': 'net_asset_value',
         '计提前单位净值': 'net_asset_value',
+        '实际净值': 'net_asset_value',
         '基金份额累计净值': 'acc_unit_value',
         '累计单位净值': 'acc_unit_value',
         '累计净值': 'acc_unit_value',
@@ -196,6 +197,14 @@ class HedgeFundNAVReader:
         df['acc_unit_value'] = df['net_asset_value']
         return df
 
+    @staticmethod
+    def _read_for_ShuangLong_LongFu2(file_path: str) -> pd.DataFrame:
+        df = pd.read_excel(file_path)
+        df = df.loc[:, df.columns.intersection(['产品名称', '产品代码', '业务日期', '单位净值', '累计单位净值', '虚拟计提净值', '虚拟后净值'])]
+        df = df.rename(columns=HedgeFundNAVReader.COLUMNS_DICT)
+        df['datetime'] = df.datetime.transform(lambda x: pd.to_datetime(str(x), infer_datetime_format=True).date())
+        return df
+
     def _notify_error_event(self, err_msg: str):
         print(f'[read_navs_and_dump_to_db] {err_msg}')
         self._wechat_bot.send_hedge_fund_nav_update_failed(err_msg)
@@ -221,7 +230,7 @@ class HedgeFundNAVReader:
         df_list: List[pd.DataFrame] = []
         for name, comp_date in data.items():
             uid, file_path = comp_date
-            if '.xls' not in name and '.xlsx' not in name and 'pdf' not in name:
+            if not name.endswith('.xls') and not name.endswith('.xlsx') and not name.endswith('.pdf'):
                 self._notify_error_event(f'not a valid file, do not process it (name){name} (file_path){file_path}')
                 continue
 
@@ -235,6 +244,8 @@ class HedgeFundNAVReader:
                 elif '天演广全' in name:
                     df = HedgeFundNAVReader._read_for_TianYanGuangQuan(file_path)
                 elif '安贤花木长盛' in name:
+                    if name.endswith('.pdf'):
+                        continue
                     df = HedgeFundNAVReader._read_for_AnXianHuaMuChangSheng(file_path)
                 elif '吾执CTA一号' in name:
                     df = HedgeFundNAVReader._read_for_WuZhiCTA1(file_path)
@@ -258,7 +269,11 @@ class HedgeFundNAVReader:
                 elif '卓识佳鑫' in name:
                     df = HedgeFundNAVReader._read_for_ZhuoShiJiaXin(file_path)
                 elif '金锝诚意精心2号' in name:
+                    if not name.endswith('.pdf'):
+                        continue
                     df = HedgeFundNAVReader._read_for_JinDeChengYiJingXin2(file_path)
+                elif '双隆-隆富2号' in name:
+                    df = HedgeFundNAVReader._read_for_ShuangLong_LongFu2(file_path)
                 else:
                     raise NotImplementedError('unknown hedge fund nav file from attachment')
             except Exception as e:
@@ -279,7 +294,7 @@ class HedgeFundNAVReader:
             except Exception as e:
                 traceback.print_exc()
                 self._notify_error_event(f'{e} (dump) (name){name} (file_path){file_path}')
-                continue
+                break
 
         if df_list:
             try:
