@@ -882,17 +882,18 @@ class FOFInfo(FOFBase):
     manager_id = Column(VARCHAR(32), primary_key=True)  # 管理端ID
     datetime = Column(CHAR(16))  # 数据日期（以支持更新操作）
     fof_name = Column(TEXT, nullable=False)  # 产品名称
-    admin = Column(TEXT, nullable=False)  # 管理人
+    desc_name = Column(CHAR(15))  # 简称
+    admin = Column(TEXT)  # 管理人
     established_date = Column(DATE, nullable=False)  # 成立日期
-    fof_status = Column(TEXT, nullable=False)  # 申赎状态等
+    fof_status = Column(CHAR(16))  # 申赎状态等
     subscription_fee = Column(DOUBLE(asdecimal=False), nullable=False)  # 认购费率
-    redemption_fee = Column(DOUBLE(asdecimal=False), nullable=False)  # 赎回费率
+    redemption_fee = Column(TEXT)  # 赎回费率
     management_fee = Column(DOUBLE(asdecimal=False), nullable=False)  # 管理费率
     custodian_fee = Column(DOUBLE(asdecimal=False), nullable=False)  # 托管费率
     administrative_fee = Column(DOUBLE(asdecimal=False), nullable=False)  # 行政管理费率
-    lock_up_period = Column(TEXT, nullable=False)  # 锁定期
-    incentive_fee_mode = Column(TEXT, nullable=False)  # 业绩报酬计提方法
-    incentive_fee = Column(TEXT, nullable=False)  # 业绩报酬提取比例
+    lock_up_period = Column(TEXT)  # 锁定期
+    incentive_fee_mode = Column(VARCHAR(31))  # 业绩报酬计提方法
+    incentive_fee = Column(VARCHAR(127))  # 业绩报酬提取比例
     incentive_fee_type = Column(VARCHAR(31))
     incentive_fee_str = Column(VARCHAR(255))
     current_deposit_rate = Column(DOUBLE(asdecimal=False))  # 银行活期存款利率
@@ -928,6 +929,9 @@ class FOFInfo(FOFBase):
     management_type = Column(VARCHAR(16))                   # 管理类型
     custodian_name = Column(VARCHAR(128))                   # 托管人名称
     fund_status = Column(VARCHAR(16))                       # 运作状态
+    fof_manager = Column(VARCHAR(16))                       # 基金经理
+    benchmark_index = Column(VARCHAR(127))                  # 基准指数
+    open_date = Column(CHAR(63))                            # 开放日
 
 
 class FOFScaleAlteration(FOFBase):
