@@ -705,6 +705,7 @@ class FOFNav(FOFBase):
     __tablename__ = 'fof_nav'
 
     fof_id = Column(CHAR(16), primary_key=True)             # 产品ID
+    manager_id = Column(CHAR(32))                           # 管理端ID
     datetime = Column(DATE, primary_key=True)               # 日期
     nav = Column(DOUBLE(asdecimal=False), nullable=False)   # 单位净值
     acc_net_value = Column(DOUBLE(asdecimal=False))         # 累计净值
@@ -712,6 +713,7 @@ class FOFNav(FOFBase):
     volume = Column(DOUBLE(asdecimal=False))                # 份额
     mv = Column(DOUBLE(asdecimal=False))                    # 市值
     ret = Column(DOUBLE(asdecimal=False))                   # 累计收益率
+    manager_id = Column(CHAR(32))                           # 管理端ID
 
 
 class FOFNavPublic(FOFBase):
@@ -723,7 +725,7 @@ class FOFNavPublic(FOFBase):
     datetime = Column(DATE, primary_key=True)               # 日期
     nav = Column(DOUBLE(asdecimal=False), nullable=False)   # 单位净值
     acc_net_value = Column(DOUBLE(asdecimal=False))         # 累计净值
-    adjusted_nav = Column(DOUBLE(asdecimal=False))  # 复权净值
+    adjusted_nav = Column(DOUBLE(asdecimal=False))          # 复权净值
     volume = Column(DOUBLE(asdecimal=False))                # 份额
     mv = Column(DOUBLE(asdecimal=False))                    # 市值
     ret = Column(DOUBLE(asdecimal=False))                   # 累计收益率
@@ -742,6 +744,7 @@ class FOFNavCalc(FOFBase):
     volume = Column(DOUBLE(asdecimal=False))                # 份额
     mv = Column(DOUBLE(asdecimal=False))                    # 市值
     ret = Column(DOUBLE(asdecimal=False))                   # 累计收益率
+    manager_id = Column(CHAR(32))                           # 管理端ID
 
 
 class FOFPosition(FOFBase):
